# Agent Starter Pack Documentation

## Overview

- [Why Use the Starter Pack?](why_starter_pack.md)
- [Available Agents](../agents/)
  - [`langgraph_base_react`](../agents/langgraph_base_react/README.md)
  - [`agentic_rag_vertexai_search`](../agents/agentic_rag_vertexai_search/README.md)
  - [`crewai_coding_crew`](../agents/crewai_coding_crew/README.md)
  - [`multimodal_live_api`](../agents/multimodal_live_api/README.md)

## Features

- [Deployment Options](deployment.md)
- [Data Ingestion Pipeline](data-ingestion.md)
- [Observability & Monitoring](observability.md)

## CLI Reference

- [Create Command](cli/create.md)
- [Setup CI/CD](cli/setup_cicd.md)

## Contributing

- [Contribution Guidelines](../CONTRIBUTING.md)
